@@ -23,4 +23,6 @@ pub mod bloom_filter;
 /// Sparse table
 pub mod sparse_table;
 /// Binary Tree
-pub mod binary_tree;
\ No newline at end of file
+pub mod binary_tree;
+/// DSU (disjoint-set-union)
+pub mod dsu;
\ No newline at end of file
